@@ -11,8 +11,7 @@ import re
 from lxml import objectify
 
 XML_API = "http://www.zdf.de/ZDFmediathek/xmlservice/web/beitragsDetails?id=%i"
-CHUNK_SIZE = 1024*1024*2 # 2 MB
-#CHUNK_SIZE = 1024*256 # 256 KB
+CHUNK_SIZE = 1024*128 # 128 KB
 
 def video_key(video):
     bitrate = 0
@@ -68,7 +67,7 @@ def main():
         basename, ext = os.path.splitext(os.path.basename(urllib.parse.urlparse(v.url.text).path))
         filename = "{title} ({basename}){ext}".format(title=title, basename=basename, ext=ext)
 
-        print("Downloading %s" % basename)
+        print("Downloading %s" % filename)
         print("  from %s" % v.url.text)
 
         size = 0
